<?php 

/**
 * Theme Options Panel.
 *
 * @package moduagency
 */

$default = moduagency_get_default_theme_options();




// Add Theme Options Panel.
$wp_customize->add_panel( 'theme_option_panel',
	array(
		'title'      => esc_html__( 'Theme Options', 'moduagency' ),
		'priority'   => 20,
		'capability' => 'edit_theme_options',
	)
);

// Global Section Start.*/

$wp_customize->add_section( 'social_option_section_settings',
	array(
		'title'      => esc_html__( 'Social Profile Options', 'moduagency' ),
		'priority'   => 120,
		'capability' => 'edit_theme_options',
		'panel'      => 'theme_option_panel',
	)
);

		/*Social Profile*/
		$wp_customize->add_setting( 'social_profile',
			array(
				'default'           => $default['social_profile'],
				'capability'        => 'edit_theme_options',
				'sanitize_callback' => 'moduagency_sanitize_checkbox',
			)
		);
		$wp_customize->add_control( 'social_profile',
			array(
				'label'    => esc_html__( 'Global Social Profile ( Nav Right )', 'moduagency' ),
				'section'  => 'social_option_section_settings',
				'type'     => 'checkbox',
				
			)
		);
		
		$wp_customize->add_setting( 'social_profile_bottom',
			array(
				'default'           => $default['social_profile_bottom'],
				'capability'        => 'edit_theme_options',
				'sanitize_callback' => 'moduagency_sanitize_checkbox',
			)
		);
		$wp_customize->add_control( 'social_profile_bottom',
			array(
				'label'    => esc_html__( 'Social Profile ( Page Bottom Right )', 'moduagency' ),
				'section'  => 'social_option_section_settings',
				'type'     => 'checkbox',
				
			)
		);
		
		/*
		Social media
		*/
		$moduagency_options['social']['fa-facebook']= array(
			'label' => esc_html__('Facebook URL', 'moduagency')
		);
		$moduagency_options['social']['fa-twitter']= array(
			'label' => esc_html__('Twitter URL', 'moduagency')
		);
		$moduagency_options['social']['fa-pinterest']= array(
			'label' => esc_html__('pinterest URL', 'moduagency')
		);
		$moduagency_options['social']['fa-youtube']= array(
			'label' => esc_html__('Youtube URL', 'moduagency')
		);
		$moduagency_options['social']['fa-instagram']= array(
			'label' => esc_html__('Instagram URL', 'moduagency')
		);
		
		foreach( $moduagency_options as $key => $options ):
			foreach( $options as $k => $val ):
				// SETTINGS
				if ( isset( $key ) && isset( $k ) ){
					$wp_customize->add_setting('moduagency_social_profile_link['.$key .']['. $k .']',
						array(
							'default'           => esc_url( $default['social_profile_link'] ),
							'capability'        => 'edit_theme_options',
							'sanitize_callback' => 'esc_url_raw'
						)
					);
					// CONTROLS
					$wp_customize->add_control('moduagency_social_profile_link['.$key .']['. $k .']', 
						array(
							'label'		 => esc_attr( $val['label'] ), 
							'section'    => 'social_option_section_settings',
							'type'       => 'url',
							
						)
					);
				}
			
			endforeach;
		endforeach;


/*Posts management section start */
$wp_customize->add_section( 'theme_option_section_settings',
	array(
		'title'      => esc_html__( 'Blog Management', 'moduagency' ),
		'priority'   => 100,
		'capability' => 'edit_theme_options',
		'panel'      => 'theme_option_panel',
	)
);

		/*Posts Layout*/
		$wp_customize->add_setting( 'blog_layout',
			array(
				'default'           => $default['blog_layout'],
				'capability'        => 'edit_theme_options',
				'sanitize_callback' => 'moduagency_sanitize_select',
			)
		);
		$wp_customize->add_control( 'blog_layout',
			array(
				'label'    => esc_html__( 'Blog Layout Options', 'moduagency' ),
				'description' => esc_html__( 'Choose between different layout options to be used as default', 'moduagency' ),
				'section'  => 'theme_option_section_settings',
				'choices'   => array(
					'pull-left'  => esc_html__( 'Primary Sidebar - Content', 'moduagency' ),
					'pull-right' => esc_html__( 'Content - Primary Sidebar', 'moduagency' ),
					'no-sidebar'    => esc_html__( 'No Sidebar', 'moduagency' ),
					),
				'type'     => 'select',
				'priority' => 170,
			)
		);
		
		
		/*content excerpt in global*/
		$wp_customize->add_setting( 'excerpt_length_blog',
			array(
				'default'           => $default['excerpt_length_blog'],
				'capability'        => 'edit_theme_options',
				'sanitize_callback' => 'moduagency_sanitize_positive_integer',
			)
		);
		$wp_customize->add_control( 'excerpt_length_blog',
			array(
				'label'    => esc_html__( 'Set Blog Excerpt Length', 'moduagency' ),
				'section'  => 'theme_option_section_settings',
				'type'     => 'number',
				'priority' => 175,
				'input_attrs'     => array( 'min' => 1, 'max' => 200, 'style' => 'width: 150px;' ),
		
			)
		);
		
		/*Blog Loop Content*/
		$wp_customize->add_setting( 'blog_loop_content_type',
			array(
				'default'           => $default['blog_loop_content_type'],
				'capability'        => 'edit_theme_options',
				'sanitize_callback' => 'moduagency_sanitize_select',
			)
		);
		$wp_customize->add_control( 'blog_loop_content_type',
			array(
				'label'    => esc_html__( 'Blog Looop Content', 'moduagency' ),
				'section'  => 'theme_option_section_settings',
				'choices'               => array(
					'excerpt-only' => __( 'Excerpt Only', 'moduagency' ),
					'full-post' => __( 'Full Post', 'moduagency' ),
					),
				'type'     => 'select',
				'priority' => 180,
			)
		);
		
		// Setting copyright_text.
		$wp_customize->add_setting( 'read_more_text',
			array(
			'default'           => $default['read_more_text'],
			'capability'        => 'edit_theme_options',
			'sanitize_callback' => 'sanitize_text_field',
			)
		);
		$wp_customize->add_control( 'read_more_text',
			array(
			'label'    => esc_html__( 'Blog Read More Text', 'moduagency' ),
			'section'  => 'theme_option_section_settings',
			'type'     => 'text',
			'priority' => 200,
			)
		);

		
		
/*Posts management section start */
$wp_customize->add_section( 'page_option_section_settings',
	array(
		'title'      => esc_html__( 'Page Management', 'moduagency' ),
		'priority'   => 100,
		'capability' => 'edit_theme_options',
		'panel'      => 'theme_option_panel',
	)
);

	
		/*Home Page Layout*/
		$wp_customize->add_setting( 'page_layout',
			array(
				'default'           => $default['blog_layout'],
				'capability'        => 'edit_theme_options',
				'sanitize_callback' => 'moduagency_sanitize_select',
			)
		);
		$wp_customize->add_control( 'page_layout',
			array(
				'label'    => esc_html__( 'Page Layout Options', 'moduagency' ),
				'section'  => 'page_option_section_settings',
				'description' => esc_html__( 'Choose between different layout options to be used as default', 'moduagency' ),
				'choices'   => array(
					'pull-left'  => esc_html__( 'Primary Sidebar - Content', 'moduagency' ),
					'pull-right' => esc_html__( 'Content - Primary Sidebar', 'moduagency' ),
					'no-sidebar'    => esc_html__( 'No Sidebar', 'moduagency' ),
					),
				'type'     => 'select',
				'priority' => 170,
			)
		);


// Header Diglog.
$wp_customize->add_section( 'topbar_container',
	array(
	'title'      => esc_html__( 'Top Bar Right', 'moduagency' ),
	'priority'   => 130,
	'capability' => 'edit_theme_options',
	'panel'      => 'theme_option_panel',
	)
);

/*Show dialog Section*/
$wp_customize->add_setting( 'topbar_defaults',
	array(
		'default'           => $default['topbar_defaults'],
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'moduagency_sanitize_checkbox',
	)
);
$wp_customize->add_control( 'topbar_defaults',
	array(
		'label'    => esc_html__( 'Show Top Bar ?', 'moduagency' ),
		'section'  => 'topbar_container',
		'type'     => 'checkbox',
		
	)
);

// Setting Phone Number.
$wp_customize->add_setting( 'topbar_phone',
	array(
	'default'           => $default['topbar_phone'],
	'capability'        => 'edit_theme_options',
	'sanitize_callback' => 'sanitize_text_field',
	)
);
$wp_customize->add_control( 'topbar_phone',
	array(
	'label'    => esc_html__( 'Top', 'moduagency' ),
	'section'  => 'topbar_container',
	'type'     => 'text',
	'priority' => 120,
	)
);

// Setting Email.
$wp_customize->add_setting( 'topbar_email',
	array(
	'default'           => $default['topbar_email'],
	'capability'        => 'edit_theme_options',
	'sanitize_callback' => 'sanitize_text_field',
	)
);
$wp_customize->add_control( 'topbar_email',
	array(
	'label'    => esc_html__( 'Top', 'moduagency' ),
	'section'  => 'topbar_container',
	'type'     => 'text',
	'priority' => 120,
	)
);

// Setting Address.
$wp_customize->add_setting( 'topbar_address',
	array(
	'default'           => $default['topbar_address'],
	'capability'        => 'edit_theme_options',
	'sanitize_callback' => 'sanitize_text_field',
	)
);
$wp_customize->add_control( 'topbar_address',
	array(
	'label'    => esc_html__( 'Top', 'moduagency' ),
	'section'  => 'topbar_container',
	'type'     => 'text',
	'priority' => 120,
	)
);


// Footer Section.
$wp_customize->add_section( 'dialog_section',
	array(
	'title'      => esc_html__( 'Dialog & Award', 'moduagency' ),
	'priority'   => 130,
	'capability' => 'edit_theme_options',
	'panel'      => 'theme_option_panel',
	)
);

	  /*Show dialog Section*/
		$wp_customize->add_setting( 'dialog_defaults',
			array(
				'default'           => $default['dialog_defaults'],
				'capability'        => 'edit_theme_options',
				'sanitize_callback' => 'moduagency_sanitize_checkbox',
			)
		);
		$wp_customize->add_control( 'dialog_defaults',
			array(
				'label'    => esc_html__( 'Show Award & Dialog ?', 'moduagency' ),
				'section'  => 'dialog_section',
				'type'     => 'checkbox',
				
			)
		);

	
 
		/*
		Award .
		*/
		$award['award_title_1']['title']= array(
			'label' => esc_html__('Award Title', 'moduagency'),
			
		);
		$award['award_title_1']['text']= array(
			'label' => esc_html__('Award Text', 'moduagency'),
			
		);
		
		$award['award_title_2']['title']= array(
			'label' => esc_html__('Award Title', 'moduagency'),
			
		);
		$award['award_title_2']['text']= array(
			'label' => esc_html__('Award Text', 'moduagency'),
			
		);
		
		$award['award_title_3']['title']= array(
			'label' => esc_html__('Award Title', 'moduagency'),
			
		);
		$award['award_title_3']['text']= array(
			'label' => esc_html__('Award Text', 'moduagency'),
			
		);
		
	
		foreach( $award as $key => $award_group ):
			foreach( $award_group as $k => $val ):
				// SETTINGS
				if ( isset( $key ) && isset( $k ) ){
					
					$wp_customize->add_setting('moduagency_award['.$key .']['. $k .']',
						array(
							'default'           => $default['moduagency_award'][$key][$k],
							'capability'     => 'edit_theme_options',
							'sanitize_callback' => 'sanitize_text_field'
						)
					);
					// CONTROLS
					$wp_customize->add_control('moduagency_award['.$key .']['. $k .']', 
						array(
							'label' => esc_html( $val['label'] ), 
							'section'    => 'dialog_section',
							'type'     => 'text',
							
						)
					);
				}
			
			endforeach;
		endforeach;

// Footer Section.
$wp_customize->add_section( 'footer_section',
	array(
	'title'      => esc_html__( 'Footer Options', 'moduagency' ),
	'priority'   => 140,
	'capability' => 'edit_theme_options',
	'panel'      => 'theme_option_panel',
	)
);

// Setting copyright_text.
$wp_customize->add_setting( 'copyright_text',
	array(
	'default'           => $default['copyright_text'],
	'capability'        => 'edit_theme_options',
	'sanitize_callback' => 'sanitize_text_field',
	)
);
$wp_customize->add_control( 'copyright_text',
	array(
	'label'    => esc_html__( 'Footer Copyright Text', 'moduagency' ),
	'section'  => 'footer_section',
	'type'     => 'text',
	'priority' => 120,
	)
);



/*Posts management section start */
$wp_customize->add_section( 'footer_call_to_action_settings',
	array(
		'title'      => esc_html__( 'Footer Call To Action', 'moduagency' ),
		'priority'   => 130,
		'capability' => 'edit_theme_options',
		'panel'      => 'theme_option_panel',
	)
);
		/*Social Profile*/
		$wp_customize->add_setting( 'active_action',
			array(
				'default'           => $default['active_action'],
				'capability'        => 'edit_theme_options',
				'sanitize_callback' => 'moduagency_sanitize_checkbox',
			)
		);
		$wp_customize->add_control( 'active_action',
			array(
				'label'    => esc_html__( 'Show Call To Action ?', 'moduagency' ),
				'section'  => 'footer_call_to_action_settings',
				'type'     => 'checkbox',
				
			)
		);

		// Call To Action.
		$wp_customize->add_setting( 'call_to_action_title',
			array(
			'default'           => $default['call_to_action_title'],
			'capability'        => 'edit_theme_options',
			'sanitize_callback' => 'sanitize_text_field',
			)
		);
		$wp_customize->add_control( 'call_to_action_title',
			array(
			'label'    => esc_html__( 'Call To Action Title', 'moduagency' ),
			'section'  => 'footer_call_to_action_settings',
			'type'     => 'text',
			'priority' => 200,
			)
		);
		
		// Call To Sub Title.
		$wp_customize->add_setting( 'call_to_action_sub',
			array(
			'default'           => $default['call_to_action_sub'],
			'capability'        => 'edit_theme_options',
			'sanitize_callback' => 'sanitize_text_field',
			)
		);
		$wp_customize->add_control( 'call_to_action_sub',
			array(
			'label'    => esc_html__( 'Call To Action Sub Title', 'moduagency' ),
			'section'  => 'footer_call_to_action_settings',
			'type'     => 'text',
			'priority' => 200,
			)
		);
		
		
		// Button.
		$wp_customize->add_setting( 'call_to_action_btn',
			array(
			'default'           => $default['call_to_action_btn'],
			'capability'        => 'edit_theme_options',
			'sanitize_callback' => 'sanitize_text_field',
			)
		);
		$wp_customize->add_control( 'call_to_action_btn',
			array(
			'label'    => esc_html__( 'Call To Action Button', 'moduagency' ),
			'section'  => 'footer_call_to_action_settings',
			'type'     => 'text',
			'priority' => 200,
			)
		);
		
		
		// Button.
		$wp_customize->add_setting( 'call_to_action_link',
			array(
			'default'           => $default['call_to_action_link'],
			'capability'        => 'edit_theme_options',
			'sanitize_callback' => 'esc_url_raw',
			)
		);
		$wp_customize->add_control( 'call_to_action_link',
			array(
			'label'    => esc_html__( 'Call To Action Button Link', 'moduagency' ),
			'section'  => 'footer_call_to_action_settings',
			'type'     => 'text',
			'priority' => 200,
			)
		);
		
		//  =============================
		//  = Image Upload              =
		//  =============================
		$wp_customize->add_setting('call_to_action_img', array(
			'default'           => esc_url( $default['call_to_action_img'] ),
			'capability'        => 'edit_theme_options',
			'sanitize_callback' => 'esc_url_raw',
		));
		$wp_customize->add_control( new WP_Customize_Image_Control($wp_customize, 'call_to_action_img', array(
			'label'    => esc_html__('Upload Action Background image', 'moduagency'),
			'section'  => 'footer_call_to_action_settings',
			'settings' => 'call_to_action_img',
		)));