<?php
/**
 * Functions hooked to post page.
 *
 * @package moduagency
 *
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}
 if ( ! function_exists( 'moduagency_posts_formats_thumbnail' ) ) :

	/**
	 * Post formats thumbnail.
	 *
	 * @since 1.0.0
	 */
	function moduagency_posts_formats_thumbnail() {
	?>
		<?php 
		$formats = get_post_format(get_the_ID());
		
		if ( has_post_thumbnail() ) :
			$post_thumbnail_id = get_post_thumbnail_id( get_the_ID() );
			$post_thumbnail_url = wp_get_attachment_url( $post_thumbnail_id );
			
		?>
           <div class="blog-media <?php echo esc_attr( $formats );?>">
           		<?php if ( is_singular() ) :?>
               		 <a href="<?php echo esc_url( $post_thumbnail_url );?>" class="image-popup">
                <?php else: ?>
                	<a href="<?php echo esc_url( get_permalink() );?>" class="image-link">
                <?php endif;?>
                <span class="style_1"><?php the_post_thumbnail('full');?></span>
                </a>
            </div>
         <?php else:?>
         	<div class="blog-media <?php echo esc_attr( $formats );?>">
           		<?php if ( !is_singular() ) :?>
            		 <span class="style_1"><img src="<?php echo esc_url( get_stylesheet_directory_uri() . "/img/palceholder.png" ); ?>" alt="" /></span>
                <?php endif;?>
                
                </a>
            </div>
         
        <?php endif;?>  
	<?php
	}

endif;
add_action( 'moduagency_posts_formats_thumbnail', 'moduagency_posts_formats_thumbnail' );


if ( ! function_exists( 'moduagency_posts_formats_video' ) ) :

	/**
	 * Post Formats Video.
	 *
	 * @since 1.0.0
	 */
	function moduagency_posts_formats_video() {
	
		$content = apply_filters( 'the_content', get_the_content(get_the_ID()) );
		$video = false;
		// Only get video from the content if a playlist isn't present.
		if ( false === strpos( $content, 'wp-playlist-script' ) ) {
			$video = get_media_embedded_in_content( $content, array( 'video', 'object', 'embed', 'iframe' ) );
		}
		
		
			// If not a single post, highlight the video file.
			if ( ! empty( $video ) ) :
				foreach ( $video as $video_html ) {
					echo '<div class="blog-media"><div class="entry-video embed-responsive embed-responsive-16by9">';
						echo $video_html;
					echo '</div></div>';
				}
			else: 
				do_action('moduagency_posts_formats_thumbnail');	
			endif;
		
		
	 }

endif;
add_action( 'moduagency_posts_formats_video', 'moduagency_posts_formats_video' ); 


if ( ! function_exists( 'moduagency_posts_formats_audio' ) ) :

	/**
	 * Post Formats audio.
	 *
	 * @since 1.0.0
	 */
	function moduagency_posts_formats_audio() {
		$content = apply_filters( 'the_content', get_the_content() );
		$audio = false;
	
		// Only get audio from the content if a playlist isn't present.
		if ( false === strpos( $content, 'wp-playlist-script' ) ) {
			$audio = get_media_embedded_in_content( $content, array( 'audio' ) );
		}
	
		
	
		// If not a single post, highlight the audio file.
		if ( ! empty( $audio ) ) :
			foreach ( $audio as $audio_html ) {
				echo '<div class="blog-media">';
					echo $audio_html;
				echo '</div>';
			}
		else: 
			do_action('moduagency_posts_formats_video');	
		endif;
	
		
	 }

endif;
add_action( 'moduagency_posts_formats_audio', 'moduagency_posts_formats_audio' ); 

if ( ! function_exists( 'moduagency_posts_formats_gallery' ) ) :

	/**
	 * Post Formats gallery.
	 *
	 * @since 1.0.0
	 */
	function moduagency_posts_formats_gallery() {
		global $post;
		if ( get_post_gallery() ) :
			echo '<div class="gallery-media owlGallery blog-media">';
			
				$gallery = get_post_gallery( $post, false );
				$ids = explode( ",", $gallery['ids'] );
				
				foreach( $ids as $id ) {
				
				   $link   = wp_get_attachment_url( $id );
				
				  echo '<div class="item"><img src="' . esc_url( $link ) . '"  class="img-responsive" alt="' .esc_attr( get_the_title() ). '" title="' .esc_attr( get_the_title() ). '"  /></div>';
				
				} 
				
			echo '</div>';
		else: 
			do_action('moduagency_posts_formats_thumbnail');	
		endif;	
	
	 }

endif;
add_action( 'moduagency_posts_formats_gallery', 'moduagency_posts_formats_gallery' ); 





if ( ! function_exists( 'moduagency_posts_formats_header' ) ) :

	/**
	 * Post moduagency_posts_blog_media
	 *
	 * @since 1.0.0
	 */
	function moduagency_posts_blog_media() {
		$formats = get_post_format(get_the_ID());
		
		switch ( $formats ) {
			default:
				do_action('moduagency_posts_formats_thumbnail');
			break;
			case 'gallery':
				do_action('moduagency_posts_formats_gallery');
			break;
			case 'audio':
				do_action('moduagency_posts_formats_audio');
			break;
			case 'video':
				do_action('moduagency_posts_formats_video');
			break;
		} 
		
	 }

endif;
add_action( 'moduagency_posts_blog_media', 'moduagency_posts_blog_media' ); 



if ( ! function_exists( 'moduagency_posts_loop_before' ) ) :

	/**
	 * Post moduagency_posts_loop_before
	 *
	 * @since 1.0.0
	 */
	function moduagency_posts_loop_before() {
	?>
        <div class="row masonry_grid"> 
        <div class="col-md-6 col-sm-6 col-xs-12 grid-sizer"></div>
	<?php
	 }

endif;
add_action( 'moduagency_posts_loop_before', 'moduagency_posts_loop_before' ); 

if ( ! function_exists( 'moduagency_posts_loop_after' ) ) :

	/**
	 * Post moduagency_posts_loop_before
	 *
	 * @since 1.0.0
	 */
	function moduagency_posts_loop_after() {
	?>
        </div>
	<?php
	 }

endif;
add_action( 'moduagency_posts_loop_after', 'moduagency_posts_loop_after',10 ); 

if ( ! function_exists( 'moduagency_posts_loop_navigation' ) ) :

	/**
	 * Post Posts Loop Navigation
	 *
	 * @since 1.0.0
	 */
	function moduagency_posts_loop_navigation() {
		if( moduagency_get_option( 'pagination_type' ) === 'default' ):
			$args = array (
			   'prev_text'          => '<i class="fa fa-long-arrow-left"></i>'. esc_html__('Previous Posts','moduagency'),
			   'next_text'          =>  esc_html__('Next Posts','moduagency').'<i class="fa fa-long-arrow-right"></i>',
			);
			echo '<div class="loop-prev-next">';
			the_posts_navigation( $args );
			echo '</div>';
		else:
			echo "<div class='clearfix'></div><div class='pagination justify-content-center'>";
			the_posts_pagination( array(
				'format' => '/page/%#%',
				'type' => 'list',
				'mid_size' => 2,
				'prev_text' => esc_html__( 'Previous', 'moduagency' ),
				'next_text' => esc_html__( 'Next', 'moduagency' ),
				'screen_reader_text' => esc_html__( '&nbsp;', 'moduagency' ),
			) );
			echo "</div>";
		endif;
	}

endif;
add_action( 'moduagency_posts_loop_after', 'moduagency_posts_loop_navigation', 11 ); 


if ( ! function_exists( 'moduagency_posts_loop_template_part' ) ) :

	/**
	 * Post Get themplate Part
	 *
	 * @since 1.0.0
	 */
	function moduagency_posts_loop_template_part( $i = 1 ) {
		
		$paged = (get_query_var('paged')) ? get_query_var('paged') : 1;
		
		if(  $i < 3 ){ 
		
		  get_template_part( 'template-parts/loop/content', get_post_format() );
		  
		}else{
			
		  get_template_part( 'template-parts/loop/content', 'grid' );
		  
		}
	}

endif;
add_action( 'moduagency_posts_loop_template_part', 'moduagency_posts_loop_template_part', 10 ); 


if ( ! function_exists( 'moduagency_single_post_navigation' ) ) :

	/**
	 * Post Single Posts Navigation 
	 *
	 * @since 1.0.0
	 */
	function moduagency_single_post_navigation( ) {
		echo '<div class="row single-prev-next">';
		$prevPost = get_previous_post(true);
		if( $prevPost ) :
			echo '<div class="col-md-6 col-sm-6 ">';
				$prevthumbnail = get_the_post_thumbnail($prevPost->ID, array(40,40) );
				previous_post_link('%link',$prevthumbnail , TRUE); 
				echo '<div class="text"><h6>'.esc_html__('Previous Article','moduagency').'</h6>';
					previous_post_link('%link',"<span>%title</span>", TRUE); 
				echo '</div>';
			echo '</div>';
			
		endif;
		
		$nextPost = get_next_post(true);
		if( $nextPost ) : 
			echo '<div class="col-md-6 col-sm-6 pull-right">';
				$nextthumbnail = get_the_post_thumbnail($nextPost->ID, array(40,40) );
				next_post_link('%link',$nextthumbnail, TRUE);
				echo '<div class="text"><h6>'.esc_html__('Next Article','moduagency').'</h6>';
					next_post_link('%link',"<span>%title</span>", TRUE);
				echo '</div>';
			echo '</div>';
			
		endif;
		echo '</div>';
	} 

endif;
add_action( 'moduagency_single_post_navigation', 'moduagency_single_post_navigation', 10 ); 


if( ! function_exists( 'moduagency_blog_loop_content_type' ) && ! is_admin() ) :

    /**
     * Excerpt length
     *
     * @since  Blog Expert 1.0.0
     *
     * @param null
     * @return int
     */
    function moduagency_blog_loop_content_type( $length ){
        $type = moduagency_get_option( 'blog_loop_content_type' );

        if ( $type === 'excerpt-only' ) {
        	the_excerpt();
        }else{
			$content = preg_replace("/<embed[^>]+>/i", "", get_the_content() , 1);
			echo strip_shortcodes( $content );
		}

        return $length;

    }

endif; 
add_action( 'moduagency_blog_loop_content_type', 'moduagency_blog_loop_content_type', 10 ); 


if( ! function_exists( 'moduagency_read_more_link' ) ) :
	/**
	* Adds custom Read More.
	*
	*/
	function moduagency_read_more_link() {
		$length = moduagency_get_option( 'read_more_text' ) != "" ? moduagency_get_option( 'read_more_text' ) : esc_html__( 'Read More', 'moduagency' );
		
		return sprintf( '<div><a class="more-link" href="%1$s">%2$s</a></div>',
			get_permalink( get_the_ID() ),
			esc_html($length)
		);
	}
	add_filter( 'the_content_more_link', 'moduagency_read_more_link' );
endif;



if( ! function_exists( 'moduagency_excerpt_more' ) ) :
	/**
	* Adds custom Read More Button to excerpt.
	*
	*/

	function moduagency_excerpt_more( $more ) {
		
		$length = moduagency_get_option( 'read_more_text' ) != "" ? moduagency_get_option( 'read_more_text' ) : esc_html__( 'Read More', 'moduagency' );
		
		return sprintf( '<div class="pull-left"><a class="more-link" href="%1$s">%2$s</a></div>',
			get_permalink( get_the_ID() ),
			esc_html($length)
		);
	}
	add_filter( 'excerpt_more', 'moduagency_excerpt_more' );
endif;


if( ! function_exists( 'moduagency_excerpt_length' ) ) :
	/**
	* Adds excerpt_length.
	*
	*/
	function moduagency_excerpt_length( $length ) {
		if( is_admin() ){
			return $length;
		}else {
		$length = moduagency_get_option( 'excerpt_length_blog' ) != "" ? moduagency_get_option( 'excerpt_length_blog' ) : 0;
		return $length;
		}
		
	}
	add_filter( 'excerpt_length', 'moduagency_excerpt_length', 999 );
endif;