<?php
/**
 * Display single product reviews (comments)
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/single-product-reviews.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see 	    https://docs.woocommerce.com/document/template-structure/
 * @author 		WooThemes
 * @package 	WooCommerce/Templates
 * @version     3.2.0
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

global $product;

if ( ! comments_open() ) {
	return;
}

?>
<div id="reviews" class="woocommerce-Reviews">
	<div id="comments" style="margin-top:20px;">
		
		<?php if ( have_comments() ) : ?>

			<ol class="commentlist">
				<?php wp_list_comments( apply_filters( 'woocommerce_product_review_list_args', array( 'callback' => 'woocommerce_comments' ) ) ); ?>
			</ol>

			<?php if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) :
				echo '<nav class="woocommerce-pagination">';
				paginate_comments_links( apply_filters( 'woocommerce_comment_pagination_args', array(
					'prev_text' => '&larr;',
					'next_text' => '&rarr;',
					'type'      => 'list',
				) ) );
				echo '</nav>';
			endif; ?>

		<?php else : ?>

			<p class="woocommerce-noreviews"><?php esc_html_e( 'There are no reviews yet.', 'moduagency' ); ?></p>

		<?php endif; ?>
	</div>

	<?php if ( get_option( 'woocommerce_review_rating_verification_required' ) === 'no' || wc_customer_bought_product( '', get_current_user_id(), $product->get_id() ) ) : ?>
	
		<div id="review_form_wrapper">
			<div id="review_form" class="comment-form row ">
				<?php
                $commenter = wp_get_current_commenter();
                
                $comment_form = array(
				/* translators:. */
                    'title_reply'          => have_comments() ? __( 'Add a review', 'moduagency' ) : sprintf( __( 'Be the first to review &ldquo;%s&rdquo;', 'moduagency' ), get_the_title() ),
					/* translators:. */
                    'title_reply_to'       => __( 'Leave a Reply to %s', 'moduagency' ),
                    'title_reply_before'   => '<div class="col-md-12"><h4>',
                    'title_reply_after'    => '</h4></div>',
					'comment_notes_before' => '<div class="col-md-12"><p class="comment-notes">' .
					__( 'Your email address will not be published.','moduagency' ).
					'</p></div>',
                    'comment_notes_after'  => '',
                    'fields'               => array(
                        'author' => '<div class="form-group col-md-6 col-sm-6">' .
                                    '<input id="author" name="author" type="text" value="' . esc_attr( $commenter['comment_author'] ) . '" size="30" aria-required="true" required  size="30" class="form-control" placeholder="' . esc_attr__( 'Name', 'moduagency' ) . '" /></div>',
                        'email'  => '<div class="form-group col-md-6 col-sm-6"> ' .
                                    '<input id="email" name="email" type="email" value="' . esc_attr( $commenter['comment_author_email'] ) . '" size="30" aria-required="true" required size="30" class="form-control"  placeholder="' . esc_attr__( 'Email', 'moduagency' ) . '" /></div>',
                    ),
                    'label_submit'  => __( 'Post Review ', 'moduagency' ),
                    'logged_in_as'  => '',
                    'comment_field' => '',
					 'class_submit'      => ' theme-btn',
					'submit_button' => '<div class="form-group col-md-12">
					<button name="%1$s" type="submit" id="%2$s" class="%3$s">%4$s</button>
					</div>'
                );
                
                if ( $account_page_url = wc_get_page_permalink( 'myaccount' ) ) {
					/* translators:. */
                    $comment_form['must_log_in'] = '<div class="col-md-12"><p class="must-log-in">' . sprintf( __( 'You must be <a href="%s">logged in</a> to post a review.', 'moduagency' ), esc_url( $account_page_url ) ) . '</p></div>';
                }
                
                if ( get_option( 'woocommerce_enable_review_rating' ) === 'yes' ) {
                    $comment_form['comment_field'] = '<div class="comment-form-rating col-md-12 col-sm-12"><label for="rating">' . esc_html__( 'Your rating', 'moduagency' ) . '</label><select name="rating" id="rating" aria-required="true" required>
                        <option value="">' . esc_html__( 'Rate&hellip;', 'moduagency' ) . '</option>
                        <option value="5">' . esc_html__( 'Perfect', 'moduagency' ) . '</option>
                        <option value="4">' . esc_html__( 'Good', 'moduagency' ) . '</option>
                        <option value="3">' . esc_html__( 'Average', 'moduagency' ) . '</option>
                        <option value="2">' . esc_html__( 'Not that bad', 'moduagency' ) . '</option>
                        <option value="1">' . esc_html__( 'Very poor', 'moduagency' ) . '</option>
                    </select></div>';
                }
                
                $comment_form['comment_field'] .=  '<div class="form-group col-md-12 col-sm-12"><textarea id="comment" name="comment" cols="45" rows="8" aria-required="true"  placeholder="' . esc_attr__( 'Your review', 'moduagency' ) . '" class="form-control"  >' .
                '</textarea></div>';
                
                
                
                comment_form( apply_filters( 'woocommerce_product_review_comment_form_args', $comment_form ) );
                ?>
			</div>
		</div>

	<?php else : ?>

		<p class="woocommerce-verification-required"><?php esc_html_e( 'Only logged in customers who have purchased this product may leave a review.', 'moduagency' ); ?></p>

	<?php endif; ?>

	<div class="clear"></div>
</div>
